<?php
/**
 * Metabox Option for Split Post
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package epic-split-post
 */

namespace EPIC\SP;

use Jeg\Form\Form_Meta_Box;

/**
 * Class Init
 *
 * @package EPIC\SP
 */
class Sp_Meta_Box {

	/**
	 * Sp_Meta_Box constructor.
	 */
	public function __construct() {
		add_action( 'plugins_loaded', array( $this, 'initialize_metabox' ) );
	}

	/**
	 * Initialize Metabox
	 */
	public function initialize_metabox() {
		$fields   = $this->metabox_fields();
		$segments = $this->metabox_segments();

		$option = array(
			'id'        => 'post_split',
			'title'     => esc_html__( 'Post Split', 'epic-sp' ),
			'post_type' => 'post',
			'type'      => 'normal',
			'fields'    => $fields,
			'segments'  => $segments,
		);

		new Form_Meta_Box( $option );
	}

	/**
	 * Metabox Segment
	 *
	 * @return array
	 */
	public function metabox_segments() {
		$segment = array();

		$segment['default'] = array(
			'name'     => esc_html__( 'Default Segment', 'epic-sp' ),
			'priority' => 1,
		);

		return $segment;
	}

	/**
	 * Metabox Fields
	 *
	 * @return array
	 */
	public function metabox_fields() {

		$fields = array();

		$fields['enable'] = array(
			'segment'     => 'default',
			'type'        => 'checkbox',
			'title'       => esc_html__( 'Enable Post Split on this Post', 'epic-sp' ),
			'description' => esc_html__( 'Enable post split on this page. Please don\'t use this feature with WordPress <!--nextpage--> feature', 'epic-sp' ),
			'default'     => false,
		);

		$fields['template'] = array(
			'segment'     => 'default',
			'type'        => 'radioimage',
			'title'       => esc_html__( 'Post Split Template', 'epic-sp' ),
			'description' => esc_html__( 'Choose post split template', 'epic-sp' ),
			'default'     => '1',
			'options'     => array(
				'1'  => EPIC_SP_URL . '/assets/img/post-split-1.png',
				'2'  => EPIC_SP_URL . '/assets/img/post-split-2.png',
				'3'  => EPIC_SP_URL . '/assets/img/post-split-3.png',
				'4'  => EPIC_SP_URL . '/assets/img/post-split-4.png',
				'5'  => EPIC_SP_URL . '/assets/img/post-split-5.png',
				'6'  => EPIC_SP_URL . '/assets/img/post-split-6.png',
				'7'  => EPIC_SP_URL . '/assets/img/post-split-7.png',
				'8'  => EPIC_SP_URL . '/assets/img/post-split-8.png',
				'9'  => EPIC_SP_URL . '/assets/img/post-split-9.png',
				'10' => EPIC_SP_URL . '/assets/img/post-split-10.png',
				'11' => EPIC_SP_URL . '/assets/img/post-split-11.png',
				'12' => EPIC_SP_URL . '/assets/img/post-split-12.png',
				'13' => EPIC_SP_URL . '/assets/img/post-split-13.png',
				'14' => EPIC_SP_URL . '/assets/img/post-split-14.png',
				'15' => EPIC_SP_URL . '/assets/img/post-split-15.png',
				'16' => EPIC_SP_URL . '/assets/img/post-split-16.png',
				'17' => EPIC_SP_URL . '/assets/img/post-split-17.png',
				'18' => EPIC_SP_URL . '/assets/img/post-split-18.png',
				'19' => EPIC_SP_URL . '/assets/img/post-split-19.png',
				'20' => EPIC_SP_URL . '/assets/img/post-split-20.png',
			),
			'dependency'  => array(
				array(
					'field'    => 'enable',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$fields['overwrite'] = array(
			'segment'     => 'default',
			'type'        => 'checkbox',
			'title'       => esc_html__( 'Overwrite split color', 'epic-sp' ),
			'description' => esc_html__( 'Enable this option to overwrite split post color', 'epic-sp' ),
			'default'     => false,
			'dependency'  => array(
				array(
					'field'    => 'template',
					'operator' => 'in',
					'value'    => array( '1', '4', '5' ),
				),
				array(
					'field'    => 'enable',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$fields['bg'] = array(
			'segment'     => 'default',
			'type'        => 'color',
			'default'     => '#f70d28',
			'title'       => esc_html__( 'Active Background Color', 'epic-sp' ),
			'description' => esc_html__( 'Background color for active post navigation', 'epic-sp' ),
			'dependency'  => array(
				array(
					'field'    => 'template',
					'operator' => 'in',
					'value'    => array( '1', '4', '5' ),
				),
				array(
					'field'    => 'enable',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'field'    => 'overwrite',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$fields['text'] = array(
			'segment'     => 'default',
			'type'        => 'color',
			'default'     => '#ffffff',
			'title'       => esc_html__( 'Active Navigation Text Color', 'epic-sp' ),
			'description' => esc_html__( 'Text color for active post navigation', 'epic-sp' ),
			'dependency'  => array(
				array(
					'field'    => 'template',
					'operator' => 'in',
					'value'    => array( '1', '4', '5' ),
				),
				array(
					'field'    => 'enable',
					'operator' => '==',
					'value'    => true,
				),
				array(
					'field'    => 'overwrite',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$fields['tag'] = array(
			'segment'     => 'default',
			'type'        => 'select',
			'title'       => esc_html__( 'Split Post by using this Tag', 'epic-sp' ),
			'description' => esc_html__( 'Your post will be split with this header as their mark', 'epic-sp' ),
			'default'     => 'h2',
			'options'     => array(
				'h1' => esc_html__( 'Heading 1 ( H1 Tag )', 'epic-sp' ),
				'h2' => esc_html__( 'Heading 2 ( H2 Tag )', 'epic-sp' ),
				'h3' => esc_html__( 'Heading 3 ( H3 Tag )', 'epic-sp' ),
				'h4' => esc_html__( 'Heading 4 ( H4 Tag )', 'epic-sp' ),
				'h5' => esc_html__( 'Heading 5 ( H5 Tag )', 'epic-sp' ),
				'h6' => esc_html__( 'Heading 6 ( H6 Tag )', 'epic-sp' ),
			),
			'dependency'  => array(
				array(
					'field'    => 'enable',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$fields['numbering'] = array(
			'segment'     => 'default',
			'type'        => 'select',
			'title'       => esc_html__( 'Split Header Numbering', 'epic-sp' ),
			'description' => esc_html__( 'Choose how your split page number used', 'epic-sp' ),
			'default'     => 'asc',
			'options'     => array(
				'desc' => esc_html__( 'Descending (ex : 3, 2, 1)', 'epic-sp' ),
				'asc'  => esc_html__( 'Ascending (ex : 1, 2, 3)', 'epic-sp' ),
			),
			'dependency'  => array(
				array(
					'field'    => 'enable',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		$fields['mode'] = array(
			'segment'     => 'default',
			'type'        => 'select',
			'title'       => esc_html__( 'Load Mode for Post Split', 'epic-sp' ),
			'description' => esc_html__( 'Choose your how your post split will load', 'epic-sp' ),
			'default'     => 'normal',
			'options'     => array(
				'normal' => esc_html__( 'Normal Load', 'epic-sp' ),
				'all'    => esc_html__( 'Load All Content', 'epic-sp' ),
				'ajax'   => esc_html__( 'Load Content with Ajax', 'epic-sp' ),
			),
			'dependency'  => array(
				array(
					'field'    => 'template',
					'operator' => 'in',
					'value'    => array( '1', '2', '3', '4', '5' ),
				),
				array(
					'field'    => 'enable',
					'operator' => '==',
					'value'    => true,
				),
			),
		);

		return $fields;
	}
}
