<?php
/**
 * @author : Jegtheme
 */

namespace EPIC\SP\Type;

/**
 * Class Theme JNews_Post_Split
 */
class Sp_Type_16 extends Sp_Type_Abstract {

	/**
	 * Render Split Content Element
	 *
	 * @return mixed
	 */
	public function render() {
		$output  = $this->before_content;
		$output .= $this->render_content();

		return $output;
	}

	/**
	 * Render Split Post Content
	 *
	 * @return null|string
	 */
	public function render_content() {
		$output = null;

		$contents = $this->splitter->get_all_result();
		$contents = $contents['content'];

		foreach ( $contents as $id => $content ) {
			$output .= "<div class='split-wrapper active' data-id='{$id}'>";
			$output .= $this->get_first_image( $content['description'] );
			$output .= $this->get_split_content( $id, $content['description'] );
			$output .= '</div>';
		}

		$output = "<div class='split-carousel owl-carousel has-nav-content top-split-nav'>{$output}</div>";

		$split_var   = 'jnews_split_' . uniqid();
		$script_json = wp_json_encode( $this->js_variable() );
		$script      = "<script> var {$split_var} = {$script_json} </script>";

		$output =
			"<div class='split-container split-template-{$this->get_split_type()}' data-id='{$split_var}'>
                {$output}
                {$script}
            </div>";

		return $output;
	}

	/**
	 * Get Page Split Content
	 *
	 * @param int    $id Page of Split Content.
	 * @param string $content Content need to be parsed.
	 *
	 * @return string
	 */
	public function get_split_content( $id, $content ) {
		$output = '';

		/* translators: 1: Page format 2: Maximum Page */
		$page_text = sprintf( esc_html__( 'Page %1$s of %2$s', 'epic-sp' ), $this->get_page_number( $id + 1 ), $this->max_page );

		$output .= "<span class='page_info'>{$page_text}</span>";
		$output .= $this->get_current_title( $id );
		$output .= $this->get_parsed_content( $content );

		$output = "<div class='split-content'>{$output}</div>";

		return $output;
	}

	/**
	 * Get current page title
	 *
	 * @param int $index Number of page.
	 *
	 * @return mixed
	 */
	public function get_current_title( $index ) {
		$title = $this->all_title[ $index ];

		return "<h3 class=\"current_title\">{$title}</h3>";
	}

	/**
	 * Get Type of Split Content
	 *
	 * @return mixed
	 */
	public function get_split_type() {
		return '16';
	}
}

