<?php
/**
 * @author : Jegtheme
 */

namespace EPIC\SP\Type;

/**
 * Class Theme Split Type Post
 */
class Sp_Type_List extends Sp_Type_Abstract {
	/**
	 * Split Post Template
	 *
	 * @var string
	 */
	protected $template;

	/**
	 * JNews_Post_Split_Abstract constructor.
	 *
	 * @param \EPIC\SP\Sp_Tool $splitter Splitter Tool.
	 * @param int              $page Current Page.
	 * @param string           $numbering Numbering Type.
	 * @param string           $mode Split Mode.
	 * @param string           $template Template Type.
	 */
	public function __construct( $splitter, $page, $numbering, $mode, $template ) {
		parent::__construct( $splitter, $page, $numbering, $mode );

		$this->template = $template;
	}

	/**
	 * Render Split Content Element
	 *
	 * @return mixed
	 */
	public function render() {
		$output  = $this->before_content;
		$output .= $this->render_content();

		return $output;
	}

	/**
	 * Render Split Content Inner Content
	 *
	 * @return mixed
	 */
	public function render_content() {
		$output = null;

		$contents = $this->splitter->get_all_result();
		$contents = $contents['content'];

		foreach ( $contents as $id => $content ) {
			$output .= '<div class="split-wrapper split-postlist active" data-id="' . $id . '">';
			$output .= $this->render_title( $id );
			$output .= apply_filters( 'epic_sp_content_description', $content['description'], $id, $this->max_page );
			$output .= '</div>';
		}

		$output = "<div class='split-container split-template-{$this->get_split_type()}'>{$output}</div>";

		return $output;
	}

	/**
	 * Render Title
	 *
	 * @param int $id title Index.
	 *
	 * @return string
	 */
	public function render_title( $id ) {
		$current = $this->page_span( $id );

		return "<h3 class=\"current_title\">{$current}</h3>";
	}

	/**
	 * Title index base on template
	 *
	 * @param int $index Title index.
	 *
	 * @return string
	 */
	public function page_span( $index ) {
		$title  = $this->all_title[ $index ];
		$number = $this->get_page_number( $index + 1 );

		switch ( $this->template ) {
			case '6':
				$page_heading =
					'<div class="pageinfo">
                        <div class="pagenum">' . str_pad( $number, 2, '0', STR_PAD_LEFT ) . '</div>
                        <div class="pagetotal">
                            <span>' . esc_html__( 'of', 'epic-sp' ) . '</span> ' . str_pad( $this->max_page, 2, '0', STR_PAD_LEFT ) . '
                        </div>
                    </div>
                    <div class="pagetitle"><span>' . $title . '</span></div>';
				break;
			case '9':
			case '10':
			case '11':
			case '12':
			case '13':
				$page_heading = '<span class="pagenum">' . $number . '</span> ' . $title;
				break;
			default:
				$page_heading = '<span class="pagenum">' . $number . '</span> ' . $title;
				break;
		}

		return $page_heading;
	}

	/**
	 * Get Type of Split Content
	 *
	 * @return mixed
	 */
	public function get_split_type() {
		return $this->template;
	}
}

